@@ -8,22 +8,33 @@
    SAFE TO REACH THEM THROUGH DOCUMENTED INTERFACES.  IN FACT, IT IS ALMOST
    GUARANTEED THAT THEY WILL CHANGE OR DISAPPEAR IN A FUTURE GMP RELEASE.
 
-Copyright 2005, 2006, 2007, 2009, 2010 Free Software Foundation, Inc.
+Copyright 2005-2007, 2009, 2010 Free Software Foundation, Inc.
 
 This file is part of the GNU MP Library.
 
 The GNU MP Library is free software; you can redistribute it and/or modify
-it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
+it under the terms of either:
+
+  * the GNU Lesser General Public License as published by the Free
+    Software Foundation; either version 3 of the License, or (at your
+    option) any later version.
+
+or
+
+  * the GNU General Public License as published by the Free Software
+    Foundation; either version 2 of the License, or (at your option) any
+    later version.
+
+or both in parallel, as here.
 
 The GNU MP Library is distributed in the hope that it will be useful, but
 WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
-License for more details.
+or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+for more details.
 
-You should have received a copy of the GNU Lesser General Public License
-along with the GNU MP Library.  If not, see http://www.gnu.org/licenses/.  */
+You should have received copies of the GNU General Public License and the
+GNU Lesser General Public License along with the GNU MP Library.  If not,
+see https://www.gnu.org/licenses/.  */
 
 
 /*
@@ -220,6 +231,8 @@ mpn_mu_bdiv_q_itch (mp_size_t nn, mp_size_t dn)
   mp_size_t qn, in, tn, itch_binvert, itch_out, itches;
   mp_size_t b;
 
+  ASSERT_ALWAYS (DC_BDIV_Q_THRESHOLD < MU_BDIV_Q_THRESHOLD);
+
   qn = nn;
 
   if (qn > dn)
@@ -236,9 +249,7 @@ mpn_mu_bdiv_q_itch (mp_size_t nn, mp_size_t dn)
 	  tn = mpn_mulmod_bnm1_next_size (dn);
 	  itch_out = mpn_mulmod_bnm1_itch (tn, dn, in);
 	}
-      itch_binvert = mpn_binvert_itch (in);
       itches = dn + tn + itch_out;
-      return in + MAX (itches, itch_binvert);
     }
   else
     {
@@ -253,8 +264,10 @@ mpn_mu_bdiv_q_itch (mp_size_t nn, mp_size_t dn)
 	  tn = mpn_mulmod_bnm1_next_size (qn);
 	  itch_out = mpn_mulmod_bnm1_itch (tn, qn, in);
 	}
-      itch_binvert = mpn_binvert_itch (in);
       itches = tn + itch_out;
-      return in + MAX (itches, itch_binvert);
     }
+
+  itch_binvert = mpn_binvert_itch (in);
+  return in + MAX (itches, itch_binvert);
 }
+
