@@ -1,6 +1,6 @@
 /* Test mpz_get_d.
 
-Copyright 2002 Free Software Foundation, Inc.
+Copyright 2002, 2012 Free Software Foundation, Inc.
 
 This file is part of the GNU MP Library test suite.
 
@@ -15,7 +15,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
 Public License for more details.
 
 You should have received a copy of the GNU General Public License along with
-the GNU MP Library test suite.  If not, see http://www.gnu.org/licenses/.  */
+the GNU MP Library test suite.  If not, see https://www.gnu.org/licenses/.  */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -32,7 +32,7 @@ check_onebit (void)
   double  got, want;
   /* FIXME: It'd be better to base this on the float format. */
 #if defined (__vax) || defined (__vax__)
-  int     limit = 127;  /* vax fp numbers have limited range */
+  int     limit = 127 - 1;  /* vax fp numbers have limited range */
 #else
   int     limit = 512;
 #endif
